0Pricing
CUDA Academy · 강의

첫 성능 향상 시간 측정하기

같은 작업에서 GPU와 CPU의 성능을 측정합니다.

첫 성능 향상 시간 측정하기은(는) CoddyKit의 무료 CUDA Academy 강의입니다. 이것은 4개 중 4번째 강의입니다. 아래에서 전체 강의를 무료로 읽을 수 있으며, 내장 코드 에디터와 24/7 AI 튜터와 함께 브라우저에서 직접 실습할 수 있습니다. 이 강의는 CUDA Academy 학습 경로의 일부이며, 진행 상황이 웹과 CoddyKit 앱에 동기화됩니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

이 강의의 일부는 아직 번역되지 않았으며 영어로 표시됩니다.

Now Measure the Win

You have a correct kernel, so the fun question is how much faster it is than the CPU. Measuring turns a guess into a real number. ⏱️

Time the CPU Baseline

Start with a fair baseline: time the same add running in a plain CPU loop. You need something to compare the GPU against.

Don't Time with the Clock Wrong

Avoid timing across a cudaMemcpy you forgot to wait for. The launch is asynchronous, so naive timers can report nonsense.

Use CUDA Events

The right tool is a pair of cudaEvent objects. They record GPU timestamps directly on the device for accurate kernel timing.

cudaEvent_t start, stop;
cudaEventCreate(&start);
cudaEventCreate(&stop);

Bracket the Kernel

Record start just before the launch and stop just after. The events queue in the stream alongside your kernel.

cudaEventRecord(start);
vecAdd<<<blocks, threads>>>(d_A, d_B, d_C, n);
cudaEventRecord(stop);

Wait, Then Read

Call cudaEventSynchronize on stop so the CPU waits for the GPU. Only then is the elapsed time ready to read.

cudaEventSynchronize(stop);
float ms = 0;
cudaEventElapsedTime(&ms, start, stop);

Warm Up First

The very first launch pays one-time setup costs. Run a throwaway warm-up launch before timing so those costs do not skew your number.

Average Several Runs

A single sample is noisy, so time the kernel a few times and take the average. Stable numbers make speedup claims trustworthy.

Count the Copies

Be honest about what you measure. Kernel-only time looks amazing, but real speedup must include the PCIe transfers too.

Compute the Speedup

Speedup is simply CPU time divided by GPU time. A small array may even be slower on the GPU once copies are counted.

float speedup = cpu_ms / gpu_ms;

Bigger Arrays Win More

The GPU shines when there is enough work to hide transfer cost. Grow n and watch the speedup climb as parallelism dominates. 📈

Quick Check

Which tool gives accurate GPU kernel timing?

Recap

You measured your first speedup with CUDA events: warm up, bracket the kernel, sync, and divide CPU by GPU time. Bigger problems, bigger wins. 🎉

자주 묻는 질문

“첫 성능 향상 시간 측정하기” 강의는 무료인가요?

네 — “첫 성능 향상 시간 측정하기” 전체 내용을 이 웹사이트에서 무료로 읽을 수 있습니다. 인터랙티브하게 실습하려면(내장 코드 에디터와 24/7 AI 튜터), CoddyKit PRO로 업그레이드하면 CUDA Academy 강의 전체를 잠금 해제할 수 있습니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

“첫 성능 향상 시간 측정하기”에서 뭘 배우나요?

같은 작업에서 GPU와 CPU의 성능을 측정합니다. 브라우저에서 직접 실행하는 실습 코드로 CUDA Academy을(를) 배우며, 24/7 AI 튜터가 강의를 진행하면서 질문에 답변해줍니다.

CUDA Academy을(를) 시작하는 데 경험이 필요한가요?

사전 경험은 필요하지 않습니다. CoddyKit의 CUDA Academy은(는) 초급자부터 고급 학습자까지를 위해 구성되어 있으므로, 여기서 시작하거나 처음부터 시작할 수 있으며 자신의 속도대로 진행할 수 있습니다. 이것은 4개 중 4번째 강의입니다.

“첫 성능 향상 시간 측정하기” 강의는 얼마나 걸리나요?

대부분의 CoddyKit 강의는 약 5~10분이 소요됩니다. 각 강의는 간결하고 인터랙티브하여 꾸준한 진행이 가능하며, 웹과 앱에서 중단한 부분부터 바로 시작할 수 있습니다.

이 CUDA Academy 강의에서 코드를 작성하고 실행할 수 있나요?

네. 모든 CUDA Academy 강의에는 내장 코드 에디터가 포함되어 있으므로, 브라우저에서 바로 실제 코드를 작성하고 실행한 후 즉시 AI 피드백을 받을 수 있습니다 — 로컬 설정이 필요 없습니다.

이 강의의 모든 강의

  1. 벡터 덧셈 커널
  2. 호스트 측 연결하기
  3. CPU에서 결과 검증하기
  4. 첫 성능 향상 시간 측정하기
← CUDA Academy(으)로 돌아가기